
% SW_INFO    Computational routines for the properties of sea water
%
% SEAWATER - developed by Phil Morgan, CSIRO
%
% DESCRIPTION:
%    SEAWATER is a toolkit of MATLAB routines for calculating the
%    properties of sea water. They are a self contained library and
%    are extremely easy to use and will run on all computers that
%    support MATLAB.
%
% MATLAB:
%    For information on MATLAB contact info@mathworks.com
%
% DISCLAIMER
%   This software is provided "as is" without warranty of any kind.
%   See the file sw_copy.m for conditions of use and licence.
%
% MORE INFORMATION:
%   http://www.marine.csiro.au/~morgan/seawater
%
% $Id: sw_info.m,v 1.1 2003/12/12 04:23:22 pen078 Exp $
% Copyright (C) CSIRO, Phil Morgan 1993.
%=========================================================================

more on
help sw_info
more off
return
%--------------------------------------------------------------------

