% SW_VER     Version number of SEAWATER library
%=========================================================================
% SW_VER    $Id: sw_ver.m,v 1.1 2003/12/12 04:23:22 pen078 Exp $
%           Copyright (C) CSIRO, Phil Morgan 1994
%
% sw_ver
%
% DESCRIPTION:
%    Returns version number of the SEAWATER library
%
% AUTHOR:  Phil Morgan, Lindsay Pender (Lindsay.Pender@csiro.au)
%
% DISCLAIMER:
%   This software is provided "as is" without warranty of any kind.
%   See the file sw_copy.m for conditions of use and licence.
%
%=========================================================================
disp('SEAWATER Version 3.0')

